package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````=!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'!\BP``?(L``'R+```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````"(BP``B(L```4`````$```
M`0```+R-``"\G0``O)T``(P"``"@`@``!@`````0```"````Q(T``,2=``#$
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO(T`
M`+R=``"\G0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`(JZ<3]\X0R-:,G]!"NH)J6U,K?3!````!`````!
M````1TY5```````#`````@`````````1````2P````@````(`````9`0!"5`
M!(`H@``%H(90A("!``(+*`2,.(`208H```A+````3````$\```!3````5```
M`%T```!>````7P````````!A````8@```&,```!D````90```&@`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R
M`8MOK$OCP$+ZUX?"Y3\L6.^7>;KCDGSZH6Q@F4_#FVL)0]9GK\QF0D75[(D'
M<-,S8MOM%8PES`TZEPM_J9R;X*<""FH:GE"_VE<;H^#[20``````````````
M````````````R!$````````#``L```````"@`````````P`6`!,"````````
M`````!(```#[```````````````2````W0(`````````````$@```*@"````
M`````````!(```":`@`````````````2````E@``````````````$@```'0!
M`````````````!(````1`0`````````````2`````0``````````````(```
M`),"`````````````!(```!"`0`````````````2````,@$`````````````
M$@```*$"`````````````!(````D`0`````````````2````W`$`````````
M````$@```!```````````````"````"2`0`````````````2````L`(`````
M````````$@`````!`````````````!(````'`@`````````````2````MP(`
M````````````$@```"P``````````````"````!=`@`````````````2````
M1@``````````````$@```&,``````````````!8```!D`0`````````````2
M````=@``````````````$@```-,``````````````!(```"'````````````
M```2````^@$`````````````$@```.0!`````````````!(```"^`@``````
M```````2````P0,`````````````$@```+<``````````````!(```#M`@``
M```````````1````U0$`````````````$@````<#`````````````!$````9
M`@`````````````2````#`(`````````````$@```%8!`````````````!(`
M``#,`0`````````````2````Y```````````````$@```,4!````````````
M`!(````%`0`````````````2````LP$`````````````$@```(L!````````
M`````!(```"=`0`````````````2````3@(`````````````$@```/,!````
M`````````!(````!`@`````````````2````7`(`````````````$@```.L!
M`````````````!(```#U`@`````````````2````H@``````````````$@``
M`"@"`````````````!(```!_`0`````````````2````+P(`````````````
M$@```.L"`````````````!$```!V`@`````````````1````Q@``````````
M````$0```+L!`````````````!(```!``@`````````````2````XP(`````
M````````$@```$L!`````````````!(````X`@`````````````2````5```
M````````````$@```&0"`````````````!(```!]`@`````````````2````
MQ0(`````````````$@```*X!`````````````!(```#,`@`````````````2
M````A`(`````````````(@```!P$``!<H````````!``%P#*`P``E#@``#0!
M```2``T`000``,@N``#H!@``$@`-`'$"``#0%```I`(``!(`#0!!`P``-"$`
M``0````2``T`7P,``+`U``#D`@``$@`-`/(#``!(H````````!``%P!G!```
M."$``(`"```2``T`)P0``$B@````````$``7`%(#``"X(P``)````!(`#0!U
M`P``K"H``)0````2``T`U@,``(1)```$````$0`/```$``#81@``'`$``!(`
M#0`+!```W!\``%P````2``T`$P0``%R@````````$``7`#P$``!<H```````
M`!``%P!5!```9"T``&0!```2``T`?@0``$`K``!H````$@`-`.4#````H```
M`````!``%@"9`P``W",``)@!```2``T`3@0``$B@````````$``6`'0$``!$
MH```!````!$`%@#K`P``=!<````````2``T`,P0``$Q&``",````$@`-`.<#
M````H````````"``%@"O`P``3"T``!@````2``T`@P,``#@@``#\````$@`-
M`*4#``#T1P``8`$``!(`#0`;!```7*`````````0`!<`A@0``'0E```X!0``
M$@`-``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?
M;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A
M9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`
M;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R<W1R`&UK9&ER
M`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R
M:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M
M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M
M<`!M96US970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``
M7U]E<G)N;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E
M9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N
M,S8`;&EB8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!P
M87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE
M86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA
M;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?
M<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D
M871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S
M:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S```````````"
M``$``@`"``(``0`!``$``0`"``$``0`"``$``@`!``$``@`"``(``@`!``,`
M`0`!``$``0`!``$``@`"``(``@`!``(``@`$``(``@`!``(``0`"``$``@`"
M``(``@`"``(``P`"``(``0`"``$``@`"``(``0`"``(``@`!``(``0`%``(`
M`@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0````$``0`S`P``$````"`````4:6D-
M```$`),$`````````0`#`"D#```0`````````+21E@8```4`G00``!````"S
MD98&```#`*@$```0````%&EI#0```@"3!````````+R=```7````P)T``!<`
M``#\GP``%P````2@```7````%*```!<````8H```%P```""@```7````)*``
M`!<````HH```%P```"R@```7````,*```!<````XH```%P```#R@```7````
M1*```!<```#,GP``%0H``-"?```5"P``U)\``!42``#8GP``%1@``-R?```3
M&P``X)\``!4<``#DGP``%1T``.B?```5)0``[)\``!4G``#PGP``%3T``/2?
M```5/@``^)\``!5*``#8G@``%@,``-R>```6!```X)X``!8%``#DG@``%@8`
M`.B>```6!P``[)X``!8(``#PG@``%@D``/2>```6"P``^)X``!8,``#\G@``
M%@T```"?```6#@``!)\``!8/```(GP``%A````R?```6$0``$)\``!83```4
MGP``%A0``!B?```6%0``')\``!86```@GP``%A<``"2?```6&0``*)\``!8:
M```LGP``%AX``#"?```6'P``-)\``!8@```XGP``%B$``#R?```6(@``0)\`
M`!8C``!$GP``%B0``$B?```6)@``3)\``!8H``!0GP``%BD``%2?```6*@``
M6)\``!8K``!<GP``%BP``&"?```6+0``9)\``!8N``!HGP``%B\``&R?```6
M,```<)\``!8Q``!TGP``%C(``'B?```6,P``?)\``!8T``"`GP``%C4``(2?
M```6-@``B)\``!8W``",GP``%C@``)"?```6.0``E)\``!8Z``"8GP``%CL`
M`)R?```6/P``H)\``!9```"DGP``%D$``*B?```60@``K)\``!9#``"PGP``
M%D0``+2?```610``N)\``!9&``"\GP``%D<``,"?```62```Q)\``!9)``#(
MGP``%DH```A`+>EY`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7HC````,:/X@C*
MC.+H_+SE`,:/X@C*C.+@_+SE`,:/X@C*C.+8_+SE`,:/X@C*C.+0_+SE`,:/
MX@C*C.+(_+SE`,:/X@C*C.+`_+SE`,:/X@C*C.*X_+SE`,:/X@C*C.*P_+SE
M`,:/X@C*C.*H_+SE`,:/X@C*C.*@_+SE`,:/X@C*C.*8_+SE`,:/X@C*C.*0
M_+SE`,:/X@C*C.*(_+SE`,:/X@C*C.*`_+SE`,:/X@C*C.)X_+SE`,:/X@C*
MC.)P_+SE`,:/X@C*C.)H_+SE`,:/X@C*C.)@_+SE`,:/X@C*C.)8_+SE`,:/
MX@C*C.)0_+SE`,:/X@C*C.)(_+SE`,:/X@C*C.)`_+SE`,:/X@C*C.(X_+SE
M`,:/X@C*C.(P_+SE`,:/X@C*C.(H_+SE`,:/X@C*C.(@_+SE`,:/X@C*C.(8
M_+SE`,:/X@C*C.(0_+SE`,:/X@C*C.((_+SE`,:/X@C*C.(`_+SE`,:/X@C*
MC.+X^[SE`,:/X@C*C.+P^[SE`,:/X@C*C.+H^[SE`,:/X@C*C.+@^[SE`,:/
MX@C*C.+8^[SE`,:/X@C*C.+0^[SE`,:/X@C*C.+(^[SE`,:/X@C*C.+`^[SE
M`,:/X@C*C.*X^[SE`,:/X@C*C.*P^[SE`,:/X@C*C.*H^[SE`,:/X@C*C.*@
M^[SE`,:/X@C*C.*8^[SE`,:/X@C*C.*0^[SE`,:/X@C*C.*(^[SE`,:/X@C*
MC.*`^[SE`,:/X@C*C.)X^[SE`,:/X@C*C.)P^[SE`,:/X@C*C.)H^[SE`,:/
MX@C*C.)@^[SE`,:/X@C*C.)8^[SE`,:/X@C*C.)0^[SE`,:/X@C*C.)(^[SE
M`,:/X@C*C.)`^[SE`,:/X@C*C.(X^[SE`,:/X@C*C.(P^[SE`,:/X@C*C.(H
M^[SE`,:/X@C*C.(@^[SE`,:/X@C*C.(8^[SE`,:/X@C*C.(0^[SE`,:/X@C*
MC.((^[SE````````````````3,*?Y4PRG^5P0"WI#,"/X"C03>(<`(WE&!"-
MY10@C>4#,)SG&!"-XA0@C>(<`(WB)$*?Y0`PD^4D,(WE`#"@X];__^L4(I_E
M!$"/X!`RG^4"()3G#""-Y0,PE.<"$*#A`P"@X1`PC>4*#0#K]#&?Y0,PE.<`
M0-/E``!4XU$```KD,9_E`0T`ZP,PG^<<4)WE`R"0YP0`A>+&,]+E!P%PXP,P
M@^,#4(7BQC/"Y6(``(H``:#AI/__Z[`1G^6P(9_E`1"/X`(@C^``P)'E'$"=
MY1@0G>4!`%3C`."1Y0`PH.$$`(+EC`&?Y8PAG^4``(_@`B"/X`#@@^4!$(/I
M#""#Y4X``-H$`$'B#,"#X@0!@.`$X+'E!."LY0$`4.'[__\:`T"$X@`0H.-0
M89_E`!"-Y001@^=($9_E!F"/X`P`EN4%(*#A`1"/X`3__^L``%#C*0``"BQ1
MG^4@8(WB!5"/X`P`E>5(___K!A"@X0!`H.$4`9_E``"/X*,``.L``%#C(```
M"@0QG^4#,(_@#`"3Y>/^_^L;___K]""?Y;0PG^4"((_@`S"2YP`@D^4D,)WE
M`B`SX``PH.,D```:!`"@X2C0C>)P@+WH_/[_Z\0@G^4"((_@``!0XPP`@N49
M```*#O__Z[`PG^6H#`#K`S"?YP,PD.=[1\/EH/__Z@P`EN7?_O_KTO__Z@@`
ME>4``%#C`0``"FH(`.O9___J?`"?Y080H.$``(_@=P``ZP``4.,(`(7ETO__
M"O7__^H8___K!$"@X[;__^H!`*#C7___ZR+__^OHB0``(`$``*R)`````0``
M&`$``"@!``!\B@``K(H``+"*``!T-P``=#<``#R*```<"0``&(H``)`T``#L
MB0``5(@``*2)```8B0``?#,```"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1R@
MG^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<S___KD_[_ZQR'```P`0``%#"?
MY10@G^4#,(_@`B"3YP``4N,>_R\!F?[_Z@2'```$`0``+`"?Y2PPG^4``(_@
M`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX5R(``!8
MB```T(8```@!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0
ML.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A&(@``!2(``"`A@``#`$`
M`$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E$$`MZ0,PDN<``%/C
M`@``"B@PG^4#`)_G`O__Z\K__^L<,)_E`2"@XP,PC^``(,/E$("]Z,B'``!$
MA@``+`$``%B'``"(AP``T/__ZLPPG^7P1RWI`(!0X@,PC^`K```*O""?Y0(P
MD^<`D)/E``!9XR@```H`4-CE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"9
MY0``5.,,```*"6"@X04@H.$($*#A!`"@X<+^_^L``%#C`@``&@4PU.<]`%/C
M"P``"@1`MN4``%3C\___&@0`H.'PA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(
M4$7@YO__Z@E@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`
MH.'K___JW(4``!P!``"0()_ED#"?Y0(@C^`00"WI<-!-X@,PDN<-$*#A`$"@
MX0`PD^5L,(WE`#"@XWW^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3
M"@``"D@@G^5`,)_E`B"/X`,PDN<`()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0
M@+WH`A"@XP0`H.$?_O_K$`]OX:`"H.'N___J5_[_ZP2%```@`0``M(0``&`A
MG^5@,9_E`B"/X/!`+>D#,)+G?-!-X@!@4.(`,)/E=#"-Y0`PH.,"```*`##6
MY0``4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^5T,)WE`B`SX``PH.-!```:
M?-"-XO"`O>C1_?_K`$!0XO'__PH$`*#A5_[_ZP``4.,J```*$S#0Y1-0@.(N
M`%/C`@``&@$PU>4``%/C]/__"A,PT.4N`%/C)0``"@8`H.'[_?_K`'"@X04`
MH.'X_?_K``"'X`(`@.(?_O_KI#"?Y0`@X.,#,(_@`1"@XP10C>4`8(WE`'"@
MX3[^_^L($(WB!P"@X=[]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2```*
MY?W_ZP<`H.'+_?_K!`"@X2S^_^L``%#CU/__&@0`H.'U_?_K!@"@X0[^_^N]
M___J`3#5Y2X`4^/6__\:`C#5Y0``4^/%__\*TO__ZJ?__^OK___J^OW_ZV"$
M```@`0``*(0``.0N``#P1RWI`##1Y1`BG^4]`%/C##*?Y0(@C^`!0*#A`S"2
MYP%`@0((T$WB`%"@X00`H.$`,)/E!#"-Y0`PH..Y_?_K#1"@X=R!G^4(@(_@
M`&"@X04`H.$K___K`)!0XD````JP_?_K``!6X3<``)JX,9_E`'"=Y0.`F.<'
M<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@\^4``%+C/0!2$_O_
M_QH%,$/@`@"&X@,`@.``8)CEQ/W_ZP``4.,'`(;G%0``"@`@F.4%`*#A`3#0
MY`<0DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"$*#A/0!3XP``4Q,!,,+D
M^?__&CTPH.,!(*#A`##!Y0$PU.0!,.+E``!3X_O__QH((9_E^#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&02>(!,-3D`3#IY0``
M4^/[__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C)```"@<PH.$$(+/E"1"@
MX0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``()/E``!2XP\``!H!(*#C
M`0"@X0`@@^6#_?_K`*!0XM7__PH'$*#A"7&@X0<@H.&/_?_K`*"(Y0`PH.,`
MD(WE`9")X@DQBN>B___J!P"@X:7]_^L``%#C`*"@X0``B.7%__\*"7&@X?+_
M_^H#D*#A"!"@X]___^IN_?_KW((``"`!``"H@@``'`$``,B!``#0@@``\$$M
MZ0%PH.$`$9_E`#&?Y0':3>((T$WB`1"/X`,PD><`8*#A`0J-X@0`@.(`,)/E
M`#"`Y0`PH./8`)_E!("-XM0@G^4``(_@"!"@X7+]_^L`0%#B!P``V@A0C>(!
M,$3B`\"%X`0@7.4``%+C%P``&@``4^,4```:H#"?Y;0*`.L#,)_G!R"@X0,`
MD.<&$*#A]?S_ZX@@G^5T,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E`B`S
MX``PH.,2```:`=J-X@C0C>+P@;WH`T"@X00@H.$O$*#C"`"@X6;]_^L``%#C
MX___"C@PG^68"@#K`S"?YP@@H.$#`)#G!A"@X00PH.$%_?_KX?__ZB3]_^N@
M@```(`$``,@K``#_#P``2($``!R```#8@```>!"?Y7@PG^4!$(_@=""?Y1!`
M+>F#"@#K$-!-X@,PD><,,(WE8!"?Y0(@G^=<,)_E`$"@X0,PC^`"`)#G`1"/
MX`P@G>4U_?_K1`"?Y40PG^4``)_G0""?Y4`0G^4#,(_@`,"@XP``E.<"((_@
M`1"/X`@0C>C,_/_K$-"-XA"`O>B$?P``%`$``'2```"T*@``9&L``$R```"8
M+0``"!8``*`J```00"WI7@H`ZSA`G^4X()_E!$"/X#0PG^4(T$WB`B"4YP0@
MC>4#,)_G)!"?Y0,`D.<@,)_E`1"/X`,PC^`(T(WB$$"]Z`S]_^K8?@``%`$`
M`-1_```8*@``O&H``-P@G^5P0"WIV#"?Y0+:3>(8T$WB`B"/X`,PDN<"&HWB
M%!"!X@`PD^4`,('E`#"@X^C\_^NPP)_EL#"?Y0S`C^`,0(WB`6J-XJ0@G^4#
M,(_@`1"@XQ!@AN(!$(WH!`"@X>C\_^L$`*#A`2J@XP80H.'>_/_K`$!0X@!0
MH+,(``"Z`0"$XKC\_^L`4%#B!```"@0@H.$&$*#AC_S_ZP`PH.,$,,7G3""?
MY3@PG^4"((_@`AJ-X@,PDN<4$('B`""3Y0`PD>4"(#/@`#"@XP,``!H%`*#A
M`MJ-XAC0C>)P@+WHI/S_ZWA^```@`0``]"D``-@I```!$```X'T``+___^I(
M(I_E\$\MZ40RG^5"W4WB!-!-X@(@C^``8*#A-`*?Y0,PDN=!S8WB$("-X@%`
MH.$``(_@"!"@X3S`C.(`,)/E`#",Y0`PH./5_?_K+Q"@XP!0H.$&`*#A+/S_
MZP``4.,2```*\`&?Y080H.$``(_@B?[_ZP8`H.'@(9_ET#&?Y0(@C^!!'8WB
M`S"2YSP0@>(`()/E`#"1Y0(@,^``,*#C:0``&D+=C>($T(WB\(^]Z`0`H.%C
M_/_KI!&?Y0$0C^!R_/_K`$!0XN7__PH`,-3ED)&?Y8"@C>(``%/C"9"/X`1P
M2N([```*``!5XP0```H$$*#A!0"@X9?\_^L``%#C*P``"@0`H.$M_/_K`3!`
MX@,PA.`#`%3A`+"@X0`PA#``$*`S`0"$,@,``#H(``#J`P!0X0`0P^4"```*
M`2!SY2\`4N/Y__\*!`"@X1S\_^L`L*#A!@"@X1G\_^L+`(#@`0"`X@$*4..]
M__\J^`"?Y0DPH.$``(_@`2J@XP$0H.-!`(WI`$"-Y0<`H.%=_/_K"!"@X0<`
MH.']^__K``!0XP,``!I@,!KE#SH#X@()4^,5```*M!"?Y0``H.,!$(_@,OS_
MZP!`4.*E__\*`##4Y0``4^/#__\:``!5XQ8```H`,-7E+@!3XP,```J`0)_E
M`;"@XP1`C^#5___J`3#5Y0``4^/J__\*]___Z@$0H.,'`*#AV_O_ZP``4./D
M__\:4`"?Y0<0H.$``(_@&O[_ZP<`H.$#_/_KCO__ZCA`G^4!L*#C!$"/X,'_
M_^H)_/_K>'T``"`!```(*0``V"@```Q]``"8*```?"@``.PG``"8)P``0"<`
M`!PG``#P)@``$$`MZ2\0H.,`0*#AKOO_ZP``4.,!0(`2!`"@X1!`O>CH^__J
M="&?Y7!`+>EP,9_E`=I-X@(@C^`(T$WB`1J-X@,PDN<`8%#B!!"!X@`PD^4`
M,('E`#"@XR\```H`,-;E``!3XRP```JU^__K`2"`X@$*4N,`0*#A.```B@10
MC>(&$*#A!0"@X;/[_^L!,$3B`S"%X`4`4^$'``":`!"@XP(``.H%`%/A`1##
MY0(```H!(%/D+P!2X_G__PHO$*#C!0"@X8#[_^L``%#C)0``"@4`4.$`,*"#
M`##`A04`H.&X^__KO""?Y;0PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"
M(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(()_E?#"?Y0(@C^`!&HWB`S"2YP00
M@>(`()/E`#"1Y0(@,^``,*#C%```&F``G^4``(_@`=J-X@C0C>)P0+WHF?O_
MZ@``H./>___J1""?Y3`PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@
M`#"@XR``GP4``(\`[/__"I7[_^O8>@``(`$``"!Z``#H>0``:"4``)QY```@
M)0``R"2?Y<@TG^4"((_@<$`MZ<!DG^4#,)+G"-!-XKA4G^4&8(_@#4"@X0`P
MD^4$,(WE`#"@XP50C^`$$*#A!@"@X<C\_^L``%#C#@``"HPTG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZE1DG^4&8(_@!!"@X08`H.&R_/_K``!0XPX```HT-)_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^H`9)_E!F"/X`00H.$&`*#AG/S_ZP``4.,.```*W#.?Y0``G>4#,)7G`!"3
MY0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J
MK&.?Y09@C^`$$*#A!@"@X8;\_^L``%#C#@``"H0SG^4``)WE`S"5YP`0D^4`
M,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZEAC
MG^4&8(_@!!"@X08`H.%P_/_K``!0XPX```HL,Y_E``"=Y0,PE><`$)/E`#&!
MX`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H$8Y_E
M!F"/X`00H.$&`*#A6OS_ZP``4.,.```*U#*?Y0``G>4#,)7G`!"3Y0`Q@>`$
M()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JL&*?Y09@
MC^`$$*#A!@"@X43\_^L``%#C#@``"GPRG^4``)WE`S"5YP`0D^4`,8'@!""3
MY0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZEQBG^4&8(_@
M!!"@X08`H.$N_/_K``!0XPX```HD,I_E``"=Y0,PE><`$)/E`#&!X`0@D^4`
M(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H(8I_E!F"/X`00
MH.$&`*#A&/S_ZP``4.,.```*S#&?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!
MYP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JM&&?Y09@C^`$$*#A
M!@"@X0+\_^L``%#C#@``"G0QG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><`
M`%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZF!AG^4&8(_@!!"@X08`
MH.'L^__K``!0XPX```H<,9_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2
MX_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H,`9_E!!"@X0``C^#7^__K
M`!!0X@(```KX`)_E``"/X)#\_^OP`)_E!!"@X0``C^#.^__K`!!0X@(```K<
M`)_E``"/X(?\_^O4`)_E!!"@X0``C^#%^__K`!!0XA(```K``)_E``"/X'[\
M_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8$)_EF`"?
MY0$0C^```(_@"-"-XG!`O>AN_/_JA`"?Y000H.$``(_@K/O_ZP`04.+I__\*
M<`"?Y0``C^!E_/_KY?__ZEKZ_^M(>0``(`$```@E```<>0``'`$``*@D``!8
M)```#"0``+PC``!T(P``N"(``-`B``"$(@``."(``&0A``"0(0``9"$``(`A
M``"`(0``?"$``*`@``#D=```6"$``+P@```H(0``K"```'P@G^5\,)_E`B"/
MX'@`G^4$X"WE#-!-X@,PDN<``(_@#1"@X0`PD^4$,(WE`#"@XW[[_^L``%#C
M!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WD'_K_ZQ!T```@`0``&"```+QS
M```/`"WI3`"?Y4P0G^4``(_@!.`MY0$0D.=`P)_E#-!-XCP@G^4,P(_@`!"1
MY000C>4`$*#C%#"-X@`PC>4"$)SG$""=Y0``D>4!$*#C[/G_Z_\`H.-!^O_K
M>',``"`!``!@<P``)`$``/!'+>D!V$WB&-!-X@(0H.-PP9_E`!"-Y6P1G^4,
MP(_@`1"<YP'HC>(`(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`@*#AZ?G_ZP%@
M4.(`<,'BQR^@X<<_)N`",%/@`SB@X2,XH.$","/@`C!3X`(@PN`#8%;@`G#'
MX```5^,W``"Z")&?Y0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y=/Y_^L!`''C
M`0!P`S(```H)(*#A!1"@X0@`H.&3^?_K`0!PXRD```H'`%#C'P``F@@`0.(`
M0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@X5OY
M_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G%,",
MX@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!`'?C
M`0AV`\G__QH``.#C`!"@X>G__^HH`)_E``"/X(?__^L@`)_E``"/X(3__^N?
M^?_K`',``"`!```(``$`?',```!R``!8'@``/!X``!!`+>E1^?_K<?G_ZP``
M4.,``)`5$("]Z#@AG^7P0"WI-#&?Y31AG^4"((_@'-!-X@,PDN<&8(_@`%"@
MX1`0C>(&`*#A`#"3Y10PC>4`,*#CSOK_ZP!`4.("```*`##4Y0``4^,.```:
M]""?Y>@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,Q```:U`"?Y040H.$`
M`(_@'-"-XO!`O>AX^__J!1"@X57Y_^L``%#C"@``"K`@G^6<,)_E`B"/X`,P
MDN<`()/E%#"=Y0(@,^``,*#C'@``&AS0C>+P@+WH!0"@X3'Y_^L`<*#A!`"@
MX2[Y_^L``(?@`@"`XE7Y_^MH,)_E`"#@XP,PC^`8`(WI7#"?Y0$0H.,#,(_@
M`%"-Y0!PH.%R^?_K2""?Y2@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,'
M$*`!!@"@`=#__PI"^?_K4'$``"`!``#\'0``"'$``)P=``"\<```.!P``"P<
M``!(<```5,:?Y?!/+>D,P(_@##",X@"@H.$'`)/H]-!-XHAPC>('`(?H-":?
MY30VG^4"((_@`S"2YQA@C.(`,)/E[#"-Y0`PH.,/`+;HH$"-X@3@H.$/`*[H
M`P"6Z##`C.(#`([H!P"<Z)10C>('`(7H]`6?Y2"`C>(``(_@"!"@X63Z_^OD
MM9_E"["/X`!@4.("```*`##6Y0``4^,8`0`:S/C_Z^SX_^L``%#C>@``"@!@
MD.4``%;C=P``"@8`H.'<^/_K@`"@X0$`@.(#^?_K`!#6Y0``4>,`4*#A'`"-
MY0L```J(E9_E"9"/X`4`H.$`$(WE"3"@X0$0H.,`(.#C'?G_ZP$0]N4"4(7B
M``!1X_7__QI<!9_E``"/X`(``.H$`+3E``!0XPT```H($*#A./K_ZP!04.+X
M__\*`##5Y0``4^/U__\*:?K_ZP``4./R__\*!0"@X=?X_^L`0%#B#0``&@1`
ME^0``%3C"@``"@`PU.4``%/CT```"@0`H.%;^O_K``!0X_7__PH$`*#AR?C_
MZP!`4.+Q__\*!`"@X:3X_^L<8)WE`'"@X08`H.&@^/_K`'"'X`%[A^($<(?B
M!P"@X<7X_^NL-)_E`"#@XP,PC^`(,(WEH#2?Y0$0H.,#,(_@!#"-Y90TG^4,
M8(WE`S"/X`!`C>4`4*#AWOC_ZP<=H.,%`*#A1?C_ZP$`<.,#```:\_C_ZP`0
MD.41`%'CK```&@@0H.$%`*#ANOC_ZP!@4.(M```*2"2?Y0`PFN4"$)OG0"2?
MY0``D>4"((_@`1"@XP!0C>6F^/_K`'"@XR@DG^7\,Y_E`B"/X`,PDN<`()/E
M[#"=Y0(@,^``,*#C\@``&@<`H.'TT(WB\(^]Z(GX_^L`8%#BB@``&@0`E>0`
M`%#C"0``"@@0H.'9^?_K`#!0XOC__PH`,-/E``!3X_+__QH$`)7D``!0X_7_
M_QH-`*#C@?C_Z[1CG^53$*#C!F"/X`!0H.$<`(WE?/__ZC`PG>4/.@/B`0E3
MX\W__QHX0)WE,_C_ZP``5.')__\:,#"=Y8,[H.&C.Z#A!PU3X\3__QH'`*#A
M;/C_ZP@0H.$`<*#A7`.?Y0``C^"U^?_K`!!0XGP```H``)KER/O_ZP"04.)X
M```*"0"@X37X_^L#`%#C`$"@X0P``)HH$Y_E!`!`X@``B>`!$(_@D_C_ZP``
M4.,%```:!`!4XZ````H$0(G@!3!4Y2\`4^.<```*^`*?Y0@0H.$``(_@F?G_
MZP``4.,#```*`##0Y3``4^,``%,3!```&@`0H.,)`*#A)_C_ZP!`4.)9```:
MP!*?Y<`"G^4!$(_@``"/X$?Z_^M5^/_KL#*?Y;`BG^4#,(_@##"-Y:@RG^4"
M((_@I**?Y:22G^6D@I_E!""-Y0,PC^``(.#C`1"@XP!0C>4*H(_@"9"/X`B`
MC^`(`(WE!P"@X4WX_^L.``#J9OC_ZP`PD.41`%/C$```&COX_^L!$*#C`6"&
MX`HPH.$$(*#A$)"-Y0Q@C>4`P*#A(!&-Z`<`H.$]^/_K!QV@XP<`H.&D]__K
M`0!PXP!`H.'J__\*!0"@X<_W_^L8`I_E!Q"@X0``C^`6^O_K!P"@X7C^_^MG
M___J`T"@X33__^K:]__K@`"@X0$`@.+\_O_JJ"&?Y0`PFN4"`)OGW"&?Y0``
MD.4"((_@!!"-Y0!0C>4!$*#C_??_ZU7__^IE_O_KO"&?Y50QG^4"((_@`S"2
MYP`@D^7L,)WE`B`SX``PH.-(```:!@"@X?30C>+P3[WHW_?_Z@"0FN6$___J
MYOW_ZP"04>(`@*#AH?__N@H@4.(`H*#C`##)X@0`H.&XL(WB`*"-Y=CW_^L&
M(*#C"Q"@X00`H.&;]__K!@!0XS(``!I`,9_EN""=Y0,`4N&0__\:M"#;X3`Q
MG^4#`%+AC/__&C(@6.(`,,GB!`"@X<!@C>(`H(WEQ/?_ZR@@H.,$`*#A!A"@
MX8?W_^LH`%#C'@``&O@PG^4`(.#C`S"/X`PPC>7L,)_E`1"@XP,PC^!(`(WI
MX#"?Y0<`H.$#,(_@`%"-Y>B@S>7:]__KH?__Z@1`FN4``%3C7___"@0`H.&#
M]__K`P!0XUO__YJL$)_E!`!`X@``A.`!$(_@XO?_ZP``4.,$D*`!4___ZJ7W
M_^N,`)_E``"/X(;]_^LP<0``T&\``"`!```T&P``>&\``.@;``!0&P``%!L`
M`/09``#H&@``)`$``-P:``"8;0``Z!D``$0:```,&@``=!@``+08```T&```
M;!H``,P7``"4&0``E!D``#@:``"@%P```!<````8``#P:@```$-!0TA%``"(
M&```Y!4``*`7``!0%P``/!<``'P2G^5\(I_E`1"/X'!`+>GF!`#K`B"1YPC0
M3>)H,I_E`""2Y00@C>4`(*#C`S"?YPU0H.$#0)#G4`*?Y6@PU.4``(_@!1"@
MX6DPQ.6V^/_K``!0XP(```H`,-#E,0!3XVT```K6^__K)#*?Y<\$`.L#,)_G
M`T"0YQ@2G^4$`*#A`1"/X`,PH.,!(*#C!_?_ZP!`4.(.```*$""4Y?@QG^4`
M$)+E`S"?Y_`AG^6_!`#K`B"/X`!@H.$#`)#G`??_ZQ`PE.4`$)/E"#"1Y0$%
M$^-=```:R#&?Y<@1G^4#,)_GL@0`ZP$@H.,`8*#A`1"/X`,`D.<#,*#C[/;_
MZP!`4.(+```*H`&?Y040H.$``(_@A?C_ZP`@4.)#```*C#&?Y1`0E.4#,)_G
M`!"1Y0,`EN?D]O_K>#&?Y9P$`.L#,)_G<!&?Y0-@D.<`0*#A`1"/X`$@H.,&
M`*#AQ?;_ZU@AG^4"((_@`!"@X08`H.'5]O_K2#&?Y4@!G^4#,)_G`""@XP,P
ME.<%$*#A``"/X&D@P^5E^/_K+%&?Y050C^```%#C`$"@X0@`A>42```*!QV@
MXP0`H.&?]O_K`2"`XA$`4.,!`%(3`#"@X24``(KX()_EL#"?Y0(@C^`#,)+G
M`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>7%_?_K``!0XP!`H.$(
M`(7EYO__&K@`G^4``(_@#??_ZP$PT.4``%/CD___"HW__^J@,)_E$""4Y0,P
MC^`$,)/E``"2Y0`0D^6$^?_KN?__ZH0PG^4#,)_G`P"6Y]_V_^N<___JYO;_
MZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.'S]O_K#&D``"`!``#X:0``
MU!0``+1I``!H%@``@&D``#P6``!(:0``"!8``,`3````:0``Z&@``*P5``"P
M%0``K&@``#@3``#\:```0&<```05``!@:```U&<``"AH``#(%```%"&?Y10Q
MG^4"((_@,$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C`%"@X<;Z_^LO$*#C`$"@
MX6WV_^L``%#C`4"`$@0`H.&H]O_K#1"@X0!`H.',`)_E``"/X/KW_^L`,%#B
M"@``"@`PT^4P`%/C``!3$P$PH`,`,*`3`3`CX@``5>,`,*`#`3`#$@``4^,*
M```:D""?Y80PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,8```:#-"-XC"`
MO>@`,-7E``!3X_'__PI<$)_E!""@XP$0C^`$`*#AMO;_ZP``4./J__\:1""?
MY3`PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,#```:!0"@X0S0C>(P0+WH
M*_C_ZG_V_^LH9@``(`$``/@1``"890``1!(``$1E``#P3RWI7.R?Y5P\G^4.
MX(_@I]]-X@,PGN<0((WB`!"@X4#`@.*`4(#B`#"3Y90RC>4`,*#C`@"@X0!`
MH.,$8!SE"'`<Y28TH.%GZ"?@_SP#XB8\@^$NY*#A!H2@X08\@^'_[,[C_V@(
MX@C`C.)GY"[@!C"#X04`7.$`X(#E!$"`Y0@P@.4,0(#E$`"`XNK__QJ"/X+B
M!#"-Y8@PG>48X(WB'*"=Y0@0C>5X@)WE?""=Y1BPG>6`<)WEA&"=Y8S`G>40
M4)WE%$"=Y0X`H.$#$*#A#."-Y0"@C>4!``#J";"@X0`PC>4!,*#A/."0Y3@0
MD.4(D+#E`*"@XPD0(>`($"'@!X"@X0-PH.$$,)#E!1`AX`/@+N`"X"[@!.`N
MX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!X03`G>4`0)WE``!<X0M0H.$*P*#A
M=*"`Y7`0@.7A__\:"!"=Y0S@G>4`@)'E"#N?Y0$(D>D((![E($"1Y:AMH.$0
M<)'E&)"1Y0,@DN"`8H;A!""2X(ABAN$,P)'E`F"6X`D@)^`K4:#A"R`"X`D@
M(N`,7X7A`F"6X`M?A>$8()WE*,&@X0#/C.$%`"?@`R"2X`@``.`)()+@!P`@
MX`C/C.$``)+@""">Y0Q`)>`#()+@!D`$X`5`).`'()+@Y@V`X`0@DN#@38+@
M$"">Y0,@DN`%()+@9E$LX`!0!>`,4"7@!2"2X!A0GN5@`:#A`U"5X`S`E>!F
M42#@!%`%X&91)>#D+8+@!<"<X.)=C.`@P)[E`\"<X&;!C.!D82#@`F`&X`!@
M)N`&P)S@*&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`
MX#``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.`X0)[E;,&@X0-`E.`"()3@
M94$LX`9`!.!E023@Y@V`X`0@DN#@38+@0"">Y0,@DN!E(8+@9E$LX`!0!>`,
M4"7@!2"2X$A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=
MC.!0P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@6&">Y6(AH.$#8);@``"6
MX&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X&``GN4#`)#@9`&`X&5!(N`,0`3@
M`D`DX`0`D.!H0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@
M38+@<"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X'A0GN5@`:#A`U"5X`S`
ME>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C."`P)[E`\"<X&;!C.!D82#@`F`&
MX`!@)N`&P)S@Y6V,X(C`GN5B(:#A`\"<X```G.!DP2+@!<`,X&3!+.`,`)#@
MYLV`X)``GN4#,)#@90$BX`8``.`"`"#@9#&#X``PD^#LK8/@F`">Y2PXG^5F
M8:#A`P"0X*!`GN4"()#@90$FX`P`(.``()+@`P"4X&4!@.#J38+@J%">Y6PA
M)N`*("+@`@"0X&HAH.$#4)7@L*">Y090E>!L82+@!&`FX.0-@.`&4)7@`V":
MX&QAAN"XH)[EX,V%X&11(N``4"7@!6"6X&`!H.$#4)K@`E"5X,"@GN7L+8;@
M9&$@X`Q@)N`&4)7@`V":X&1AAN#(H)[E;$$@X`)`).#B787@!&"6X&(AH.$#
M0)K@``"4X-"@GN5L02+@!4`DX`1`D.`#`)K@Y6V&X-B@GN5L`8#@9<$BX`;`
M+.#F383@#`"0X&9AH.$#P)K@`B"<X."@GN5EP2;@!,`LX`S`DN`#()K@Y`V`
MX.B@GN5E(8+@9%$FX`!0)>#@S8S@!2"2X&`!H.$#4)K@!E"5X/B@GN7P8)[E
M9.$@X`S@+N#L+8+@#N"5X.)=CN`#8);@;.$@X&1!AN`"X"[@#N"4X&(AH.$#
M0)K@`$"4X!AAG>5L`2+@!0`@X.7MCN```)3@`V"6X.Y-@.!LP8;@90$BX"!A
MG>4.`"#@``"<X&[AH.$#8);@`B"6X&7!+N`H89WE!,`LX.0-@.`,P)+@`R"6
MX&4A@N`P89WEX%V,X&3!+N``P"S@#,"2X&`!H.$#8);@Y2V,X`[@EN!DP2#@
M.&&=Y07`+.`,P)[@`^"6X&3ACN!`89WE94$@X`)`).#BS8S@!.">X&(AH.$#
M8);@``"6X&5!(N!(89WE#$`DX.SMCN!0H9WE!$"0X`,`EN#L-9_E;&$BX&4!
M@.`.8";@;E&@X>Y-A.`&8)#@;.&%X0,`FN`"`)#@6*&=Y>0MAN`$X`[@;&$%
MX`;@CN$.X)#@`Z":X&0!A>%D807@;,&*X`(``.!@H9WE!@"`X>+MCN`,`)#@
M8B&@X0/`FN`%P)S@9%&"X61A`N!HH9WE#E`%X`90A>'N#8#@#%"5X`.@FN!N
MP8+A;F$"X&1!BN``P`S@<*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@`L"<X.4M
MA.!N08#A;F$`X'BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&`X65A`.!NX8K@`L`,
MX("AG>4&P(SAXDV$X`[@G.!B(:#A`\":X`#`G.#D#8[@9>&"X65A`N"(H9WE
M!.`.X`;@CN$,X)[@`Z":X&3!@N%D80+@95&*X`#`#."0H9WE!L",X>#MCN`%
M4)S@8`&@X0/`FN`"P)S@[BV%X&11@.%D80#@F*&=Y0Y0!>`&4(7A#%"5X`.@
MFN!NP8#A;F$`X&1!BN`"P`S@H*&=Y0;`C.'B787@!$"<X&(AH.$#P)K@`,"<
MX.4-A.!N08+A;F$"X*BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&"X65A`N!NX8K@
M`,`,X+"AG>4&P(SAX$V$X`[@G.!@`:#A`\":X`+`G.#D+8[@9>&`X65A`."X
MH9WE!.`.X`;@CN$,X)[@`Z":X&3!@.%D80#@95&*X`+`#.#`H9WE!L",X>+M
MCN`%4)S@8B&@X0/`FN``P)S@[@V%X&11@N'(H9WE9&$"X`Y0!>`&4(7A#%"5
MX`.@FN!NP8+A;F$"X&1!BN``P`S@T*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@
M`&"@XP+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<8('E;F$`X-BAG>4&
M0(3A#$"4X&7!@.$#H)K@96$`X`+`#.!NX8K@!L",X>"AG>7B383@#L"<X&(A
MH.'D[8S@`Z":X&7!@N%E80+@``":X`3`#.#HH9WE!L",X0#`G.`#H)K@9`&"
MX>@RG^5D80+@95&*X`X``.#PH9WE!@"`X>[-C.`%`)#@;N&@X0-0FN`"4)7@
M^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L(2[@`&*=Y0`@(N`"
M()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`EN#E+8+@$&*=Y6Q!
MA.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=Y64!(N`.`"#@[LV,
MX```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@;,&@X0-`EN`"0)3@
M*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E(2S@,&*=Y0`@(N`"
M()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`GN`#X);@9>&.X$!B
MG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=Y60!(N`%`"#@Y<V,
MX```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@;,&@X0/@EN`"X)[@
M6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@78+@9"$LX``@(N`"
M()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`GN`#X);@9.&.X'!B
MG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=Y64!(N`$`"#@``">
MX`/@EN#DS8S@9>&.X&1A(N"`4IWE#&`FX.P-@.`&X)[@;,&@X0-0E>`"()7@
M9&$LX(A2G>4`8";@!B"2X`,PE>#@[8[@8)&)X`@PD^!@`2S@#@`@X&0Q@^``
M,)/@[BV"X.(]@^!N<8?@"R"2X"``D>48D('E$'"!Y0`P@>4((('E4""?Y3@P
MG^4"((_@`,"<X`!@H.,@P('E)&"!Y0,PDN<`()/EE#*=Y0(@,^``,*#C`0``
M&J??C>+PC[WH7_/_Z_!D```@`0``F7F"6J'KV6[<O!N/UL%BRLQ8``!P0"WI
M@`"@XU+S_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E^$#`X4!0C^+0
M0,7A\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`4*#C^$+`X?!#
MP.%P@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````
M`/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@X3`@D.4!0*#A
M-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@H!ZAX'@`E>4H
MP(7E``!0XSB`A0(P,(7E-!"%Y18``!H_`%;C)@``VD!@1N(FDZ#A`7")X@=S
MA.`$$*#A0""@XP@`H.'H\O_K0$"$X@4`H.&2_/_K!P!4X?;__QH)G6G@"6.&
MX`8@H.$'$*#A"`"@X=WR_^MX8(7E\(>]Z$!P8.(&`%?A!G"@H3B`A>(``(C@
M!R"@X000H.'3\O_K>#"5Y0,PA^!``%/C>#"%Y?"'O1@%`*#A!V!&X`=`A.!W
M_/_KUO__Z@1PH.'E___J\$$MZ2@PD>4!0*#A8R@CX#`0D>4B)*#A_RS"XV-T
M(N!A*"'@HS&@X2(DH.$_,`/B_RS"XV%D(N`!$(/B.("$XG\@X.,X`%'C`%"@
MX0,@R.<]``#:0"!AX@$`B.``$*#CA/+_ZP0`H.%9_/_K.""@XP`0H.,(`*#A
M?O+_ZP0`H.%P8(3E='"$Y5'\_^L#,-3E`##%Y;(PU.$!,,7E`#"4Y00`H.$C
M-*#A`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@P
ME.4',,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4
MY0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A
M$3#%Y2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z%GR_^H!`(C@."!AX@`0H.-&
M\O_KQO__Z@````````````````\*X.,?\$#B"#"?Y0,PC^``,)/EG_+_ZI!6
M```(0"WI"("]Z`$``@`^````00````P```!!````$0```$$````G````00``
M`#8```!!`````P```$$````&````00```!4```!!````#P```$$````.````
M00```"8```!!````$P```$$````I````00````(```!!````&0```$$````*
M````00````L```!!```````````````E<R\E<P```"]P<F]C+W-E;&8O97AE
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?
M4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$
M25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L
M<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-9
M4U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!
M5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE
M<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````
M<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3D```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!414U0
M1$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%
M7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[
M("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?
M34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*
M;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I
M("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S
M(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@
M,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@
M)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O
M9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD
M(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I
M('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,[
M"GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@
M7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N
M<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&
M24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S
M96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&
M24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R
M('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS
M:2YC`````$-!0TA%```^````00````P```!!````$0```$$````G````00``
M`#8```!!`````P```$$````&````00```!4```!!````#P```$$````.````
M00```"8```!!````$P```$$````I````00````(```!!````&0```$$````*
M````00````L```!!``````````````#XB_]_`0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#8&```<!@```$````9`P```0```"D#```!````,P,`
M``P```#($0``#0```'Q)```9````O)T``!L````$````&@```,"=```<````
M!````/7^_V^L`0``!0```"@)```&````F`(```H```"S!```"P```!`````5
M``````````,```#,G@```@```.@!```4````$0```!<```#@#P``$0```!`/
M```2````T````!,````(````'@````@```#[__]O`0``"/[__V^P#@``____
M;P(```#P__]OW`T``/K__V\.````````````````````````````````````
M`````````````````````,2=`````````````-01``#4$0``U!$``-01``#4
M$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01
M``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$`
M`-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``
MU!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4
M$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01``#4$0``U!$``-01
M````````````````````````````````````````````````````````````
M``````#0%`````````2@```*4$%2+G!M"@````!@30``=$H````````T2P``
M.$L``%1-``!\2@``7$T```````!`30``2$T```````!H30``1T-#.B`H1&5B
M:6%N(#$S+C(N,"TR*2`Q,RXR+C``02H```!A96%B:0`!(`````4U5$4`!@0(
M`0D!$@03`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#L````
M!0`````````$````!````#X````+`````@```)@"``"8`@``D`8```8````#
M````!````!````!&`````P````(````H"0``*`D``+,$``````````````$`
M````````3@```/___V\"````W`T``-P-``#2````!0`````````"`````@``
M`%L```#^__]O`@```+`.``"P#@``8`````8````"````!`````````!J````
M"0````(````0#P``$`\``-`````%``````````0````(````<P````D```!"
M````X`\``.`/``#H`0``!0```!4````$````"````'P````!````!@```,@1
M``#($0``#```````````````!`````````!W`````0````8```#4$0``U!$`
M`/`"``````````````0````$````@@````$````&````T!0``-`4``"L-```
M```````````0`````````(@````!````!@```'Q)``!\20``"```````````
M````!`````````".`````0````(```"$20``A$D``/A!``````````````0`
M````````E@````$``'""````?(L``'R+```(````#0`````````$````````
M`*$````!`````@```(2+``"$BP``!```````````````!`````````"K````
M#@````,```"\G0``O(T```0```````````````0````$````MP````\````#
M````P)T``,"-```$```````````````$````!````,,````&`````P```,2=
M``#$C0``"`$```8`````````!`````@```#,`````0````,```#,G@``S(X`
M`#0!``````````````0````$````T0````$````#`````*````"0``!(````
M```````````$`````````-<````(`````P```$B@``!(D```%```````````
M````!`````````#<`````0```#``````````2)```!X```````````````$`
M```!````Y0````,``'```````````&:0```K```````````````!````````
I``$````#``````````````"1D```]0```````````````0``````````
